/*
 * Copyright (C) 2011 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Modified by Vinay S Shenoy on 19/5/13
 */

package com.android.volley;

import android.content.Intent;

import com.android.volley.NetworkResponse;
import com.android.volley.VolleyError;

/**
 * Error indicating that there was an authentication failure when performing a Request.
 */
@SuppressWarnings("serial")
public class AuthFailureError extends VolleyError {
    /** An intent that can be used to resolve this exception. (Brings up the password dialog.) */
    private Intent mResolutionIntent;

    public AuthFailureError() {
        errorCode = ErrorCode.AUTH_FAILURE_ERROR;
    }

    public AuthFailureError(Intent intent) {
        mResolutionIntent = intent;
        errorCode = ErrorCode.AUTH_FAILURE_ERROR;
    }

    public AuthFailureError(NetworkResponse response) {
        super(response);
        errorCode = ErrorCode.AUTH_FAILURE_ERROR;
    }

    public AuthFailureError(String message) {
        super(message);
        errorCode = ErrorCode.AUTH_FAILURE_ERROR;
    }

    public AuthFailureError(String message, Exception reason) {
        super(message, reason);
        errorCode = ErrorCode.AUTH_FAILURE_ERROR;
    }

    public Intent getResolutionIntent() {
        return mResolutionIntent;
    }

    @Override
    public String getMessage() {
        if (mResolutionIntent != null) {
            return "User needs to (re)enter credentials.";
        }
        return super.getMessage();
    }
}
